@@ -814,14 +814,17 @@ from .{identity_name}_objects import *
 
 
 from fastapi import APIRouter, FastAPI
+from fastapi.staticfiles import StaticFiles
+from starlette.responses import FileResponse 
 from fastapi.middleware.cors import CORSMiddleware
 import uvicorn
+import os
 
 
 router = APIRouter()
 
 
-class Service_test_protobuff_code:
+class Service_{identity_name}:
 {service_class_function_list_text}
 
 
@@ -829,7 +832,7 @@ def init(service_instance: Any):
 {service_api_function_list_text}
 
 
-def run(service_instance: Any, port: str):
+def run(service_instance: Any, port: str, html_folder_path: str="", serve_html_under_which_url: str="/"):
     init(service_instance=service_instance)
 
     app = FastAPI()
@@ -845,7 +848,20 @@ def run(service_instance: Any, port: str):
         prefix="/{identity_name}",
     )
 
-    print(f"You can see the docs here: http://127.0.0.1:{{port}}/docs")
+    if (html_folder_path != ""):
+        if os.path.exists(html_folder_path) and os.path.isdir(html_folder_path):
+            app.mount(serve_html_under_which_url, StaticFiles(directory=html_folder_path, html = True), name="web")
+            @app.get(serve_html_under_which_url, response_model=str)
+            async def index_page():
+                return FileResponse(os.path.join(html_folder_path, 'index.html'))
+            @app.exception_handler(404) #type: ignore
+            async def custom_404_handler(_, __): #type: ignore
+                return FileResponse(os.path.join(html_folder_path, 'index.html'))
+            print(f"The website is running at: http://127.0.0.1:{{port}}/")
+        else:
+            print(f"Error: You should give me an absolute html_folder_path than {{html_folder_path}}")
+
+    print(f"You can see the docs here: http://127.0.0.1:{{{{port}}}}/docs")
     uvicorn.run( #type: ignore
         app=app,
         host="0.0.0.0",
@@ -854,7 +870,7 @@ def run(service_instance: Any, port: str):
 
 
 if __name__ == "__main__":
-    service_instance = Service_test_protobuff_code()
+    service_instance = Service_{identity_name}()
     run(service_instance, port="6060")
         """.strip()
 
@@ -1292,7 +1308,8 @@ export class {class_name} {{
     }}
 
     _clone(): {class_name} {{
-        return structuredClone(this)
+        let clone = Object.assign(Object.create(Object.getPrototypeOf(this)), this)
+        return clone
     }}
 
     from_dict(item: _{class_name}): {class_name} {{
@@ -1319,6 +1336,107 @@ export class {class_name} {{
         template_text = f"""
 const _ygrpc_official_types = ["string", "number", "boolean"];
 
+export const clone_object_ = (obj: any) =>  JSON.parse(JSON.stringify(obj));
+
+export const get_secret_alphabet_dict_ = (a_secret_string: string) =>  {{
+    const ascii_lowercase = "abcdefghijklmnopqrstuvwxyz".split("")
+    const number_0_to_9 = "0123456789".split("")
+
+    var new_key = a_secret_string.replace(" ", "").toLowerCase().split("")
+    var character_list: string[] = []
+    for (var char of new_key) {{
+        if ((/[a-zA-Z]/).test(char)) {{
+            if (!character_list.includes(char)) {{
+                character_list.push(char)
+            }}
+        }}
+    }}
+
+    if (character_list.length >= 26) {{
+        character_list = character_list.slice(0, 26)
+    }} else {{
+        var characters_that_the_key_didnt_cover: string[] = []
+        for (var char of ascii_lowercase) {{
+            if (!character_list.includes(char)) {{
+                characters_that_the_key_didnt_cover.push(char)
+            }}
+        }}
+        character_list = character_list.concat(characters_that_the_key_didnt_cover) 
+    }}
+
+    var final_dict = {{}} as Record<string, string>
+
+    // for alphabet
+    for (let [index, char] of ascii_lowercase.entries()) {{
+        final_dict[char] = character_list[index]
+    }}
+
+    // for numbers
+    var original_numbers_in_alphabet_format = ascii_lowercase.slice(0, 10) // 0-9 representations in alphabet format
+    var secret_numbers_in_alphabet_format = Object.values(final_dict).slice(0, 10)
+    var final_number_list = [] as string[]
+    for (var index in number_0_to_9) {{
+        var secret_char = secret_numbers_in_alphabet_format[index]
+        if (original_numbers_in_alphabet_format.includes(secret_char)) {{
+            final_number_list.push(String(original_numbers_in_alphabet_format.findIndex((x) => x===secret_char)))
+        }}
+    }}
+    if (final_number_list.length >= 10) {{
+        final_number_list = final_number_list.slice(0, 10)
+    }} else {{
+        var numbers_that_didnt_get_cover = [] as string[]
+        for (var char of number_0_to_9) {{
+            if (!final_number_list.includes(char)) {{
+                numbers_that_didnt_get_cover.push(char)
+            }}
+        }}
+        final_number_list = final_number_list.concat(numbers_that_didnt_get_cover)
+    }}
+    for (let [index, char] of final_number_list.entries()) {{
+        final_dict[String(index)] = char
+    }}
+
+    return final_dict
+}};
+
+export const encode_message_ = (a_secret_dict: Record<string, string>, message: string):string => {{
+    var new_message = ""
+    for (const char of message) {{
+        if ((!(/[a-zA-Z]/).test(char)) && (!(/^\d$/).test(char))) {{
+            new_message += char
+            continue
+        }}
+        var new_char = a_secret_dict[char.toLowerCase()]
+        if ((/[A-Z]/).test(char)) {{
+            new_char = new_char.toUpperCase()
+        }}
+        new_message += new_char
+    }}
+    return new_message
+}}
+
+export const decode_message_ = (a_secret_dict: Record<string, string>, message: string):string => {{
+    var new_secret_dict = {{}} as Record<string, string>
+    for (var key of Object.keys(a_secret_dict)) {{
+        new_secret_dict[a_secret_dict[key]] = key
+    }}
+    a_secret_dict = new_secret_dict
+
+    var new_message = ""
+    for (const char of message) {{
+        if ((!(/[a-zA-Z]/).test(char)) && (!(/^\d$/).test(char))) {{
+            new_message += char
+            continue
+        }}
+        var new_char = a_secret_dict[char.toLowerCase()]
+        if ((/[A-Z]/).test(char)) {{
+            new_char = new_char.toUpperCase()
+        }}
+        new_message += new_char
+    }}
+    return new_message
+}}
+
 const _general_to_dict_function = (object: any): any => {{
     let the_type = typeof object
     if (the_type == "object") {{
@@ -1373,7 +1491,6 @@ const _general_from_dict_function = (old_object: any, new_object: any): any => {
                     keys = Object.keys(old_object._property_name_to_its_type_dict)
                     for (const key of keys) {{
                         if (Object.keys(new_object).includes(key)) {{
-                            console.log((typeof old_object._property_name_to_its_type_dict[key]))
                             if ((typeof old_object._property_name_to_its_type_dict[key]) == "string") {{
                                 // default value type
                                 old_object[key] = new_object[key]
@@ -1430,7 +1547,7 @@ const _general_from_dict_function = (old_object: any, new_object: any): any => {
     async {function_name}(item: {identity_name}_objects.{input_variable}, ignore_error?: boolean): Promise<{identity_name}_objects.{output_variable} | null> {{
         let result = await this._get_reponse_or_error_by_url_path_and_input("{function_name}", item.to_dict())
         if (Object.keys(result).includes(this._special_error_key)) {{
-            if ((ignore_error != null) && (!ignore_error)) {{
+            if ((ignore_error == null) || ((ignore_error != null) && (!ignore_error))) {{
                 this._error_handle_function(result[this._special_error_key])
             }}
             return null
@@ -1460,6 +1577,18 @@ export class Client_{identity_name} {{
         if (service_url.endsWith("/")) {{
             service_url = service_url.slice(0, service_url.length-1);
         }}
+        try {{
+            if (location.protocol === 'https:') {{
+                if (service_url.startsWith("http:")) {{
+                    service_url = service_url.replace("http:", "https:")
+                }}
+            }} else if (location.protocol === 'http:') {{
+                if (service_url.startsWith("https:")) {{
+                    service_url = service_url.replace("https:", "http:")
+                }}
+            }}
+        }} catch (e) {{
+        }}
         this._service_url = service_url
         
         if (header != null) {{
@@ -1485,7 +1614,7 @@ export class Client_{identity_name} {{
             }});
             return await response.json()
         }} catch (e) {{
-            return {{_special_error_key: String(e)}};
+            return {{[this._special_error_key]: String(e)}};
         }}
     }}
 
